<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AddClock</name>
    <message>
        <source>Add Log Clock</source>
        <translation type="obsolete">Přidat nové hodiny zápisu</translation>
    </message>
    <message>
        <source>&amp;New Clock Name:</source>
        <translation>&amp;Název nových hodin:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Add Clock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddEvent</name>
    <message>
        <source>Add Log Event</source>
        <translation>Přidat událost zápisu</translation>
    </message>
    <message>
        <source>&amp;New Event Name:</source>
        <translation>&amp;Název nové události:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
</context>
<context>
    <name>ClockListView</name>
    <message>
        <source>Edit Event</source>
        <translation>Upravit událost</translation>
    </message>
</context>
<context>
    <name>EditClock</name>
    <message>
        <source>Edit Clock:</source>
        <translation type="obsolete">Upravit hodiny:</translation>
    </message>
    <message>
        <source>Code:</source>
        <translation>Kód:</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Začátek</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Konec</translation>
    </message>
    <message>
        <source>Event</source>
        <translation>Událost</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
    <message>
        <source>Count</source>
        <translation>Počet</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Přidat</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Upravit</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>S&amp;mazat</translation>
    </message>
    <message>
        <source>Scheduler
Rules</source>
        <translation>Pravidla pro
rozvrhovač</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Uložit</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Uložit &amp;jako</translation>
    </message>
    <message>
        <source>&amp;Services
List</source>
        <translation>Seznam
&amp;služeb</translation>
    </message>
    <message>
        <source>Colo&amp;r</source>
        <translation>&amp;Barva</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation type="obsolete">Jste si jistý, že chcete smazat</translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation>Smazat událost</translation>
    </message>
    <message>
        <source>Clock Modified</source>
        <translation>Hodiny změněny</translation>
    </message>
    <message>
        <source>The clock has been modified.
Do you want to save?</source>
        <translation>Hodiny byly změněny.
Chcete je uložit?</translation>
    </message>
    <message>
        <source>Missing Clock Code</source>
        <translation>Chybí kód hodin</translation>
    </message>
    <message>
        <source>You must specify a clock code!</source>
        <translation>Musíte zadat kód hodin!</translation>
    </message>
    <message>
        <source>Code Exists</source>
        <translation>Kód existuje</translation>
    </message>
    <message>
        <source>The clock code is already in use!</source>
        <translation>Kód hodin se již používá!</translation>
    </message>
    <message>
        <source>Clock Exists</source>
        <translation>Hodiny existují</translation>
    </message>
    <message>
        <source>Clock already exists!  Overwrite?</source>
        <translation>Hodiny již existují! Přepsat?</translation>
    </message>
    <message>
        <source>--- End of clock ---</source>
        <translation type="obsolete">--- Konec hodin ---</translation>
    </message>
    <message>
        <source>Invalid Code</source>
        <translation>Neplatný kód</translation>
    </message>
    <message>
        <source>You must provide a clock code!</source>
        <translation>Musíte zadat kód hodin!</translation>
    </message>
    <message>
        <source>Duplicate Code</source>
        <translation>Zdvojený kód</translation>
    </message>
    <message>
        <source>That code is already in use!</source>
        <translation>Tento kód se již používá!</translation>
    </message>
    <message>
        <source>Remarks</source>
        <translation type="obsolete">Poznámky</translation>
    </message>
    <message>
        <source>&amp;Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Clock</source>
        <translation type="unfinished">Upravit hodiny</translation>
    </message>
    <message>
        <source>Are you sure you want to delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>That event does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>USER NOTES</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trans</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEvent</name>
    <message>
        <source>Editing Event</source>
        <translation>Upravit událost</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Skupina:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <source>Audio Only</source>
        <translation>Pouze zvuk</translation>
    </message>
    <message>
        <source>Macros Only</source>
        <translation>Pouze makra</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="obsolete">VOZÍK</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">SKUPINA</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">DÉLKA</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">NÁZEV</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">UMĚLEC</translation>
    </message>
    <message>
        <source>START</source>
        <translation type="obsolete">ZAČÁTEK</translation>
    </message>
    <message>
        <source>END</source>
        <translation type="obsolete">KONEC</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="obsolete">TYP</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>VŠE</translation>
    </message>
    <message>
        <source>PRE-POSITION LOG</source>
        <translation>ZÁPIS PŘED-POLOHY</translation>
    </message>
    <message>
        <source>Cue to this event</source>
        <translation>CUE k této události</translation>
    </message>
    <message>
        <source>before scheduled start.  (First cart will have a STOP transition.)</source>
        <translation>před naplánovaným začátkem. (První vozík bude mít přechod ZASTAVENÍ.)</translation>
    </message>
    <message>
        <source>TIMED START</source>
        <translation>PEVNÝ ZAČÁTEK</translation>
    </message>
    <message>
        <source>Use hard start time</source>
        <translation>Použít pevný počáteční čas</translation>
    </message>
    <message>
        <source>Make Post Point</source>
        <translation type="obsolete">Udělat bod vyvěšení</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Činnost, když předchozí událost ještě běží</translation>
    </message>
    <message>
        <source>Start immediately</source>
        <translation>Spustit ihned</translation>
    </message>
    <message>
        <source>Make next</source>
        <translation>Jako další</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Počkat až do</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Přechod</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <source>Transition if previous event ends before start time:</source>
        <translation type="obsolete">Přechod, když předchozí událost končí před počátečním časem:</translation>
    </message>
    <message>
        <source>ENFORCING LENGTH</source>
        <translation>VYNUCENÁ DÉLKA</translation>
    </message>
    <message>
        <source>Use AutoFill</source>
        <translation>Použít automatické vyplnění</translation>
    </message>
    <message>
        <source>Warn if fill is over or under</source>
        <translation>Varovat, když je automatické vyplnění větší nebo menší</translation>
    </message>
    <message>
        <source>by at least</source>
        <translation>než alespoň</translation>
    </message>
    <message>
        <source>Use Timescaling</source>
        <translation>Použít změnu času</translation>
    </message>
    <message>
        <source>TRANSITION</source>
        <translation type="obsolete">PŘECHOD</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation type="obsolete">POČÍTADLO</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádný</translation>
    </message>
    <message>
        <source>From Traffic</source>
        <translation>Z přenosu</translation>
    </message>
    <message>
        <source>From Music</source>
        <translation>Z hudby</translation>
    </message>
    <message>
        <source>Select from:</source>
        <translation>Vybrat z:</translation>
    </message>
    <message>
        <source>Title Separation</source>
        <translation>Odstup názvů</translation>
    </message>
    <message>
        <source>Must have code</source>
        <translation>Vynutit kód</translation>
    </message>
    <message>
        <source>Import carts scheduled</source>
        <translation>Rozvrženy vozíky zavedení</translation>
    </message>
    <message>
        <source>prior to the start of this event.</source>
        <translation>před začátkem této události.</translation>
    </message>
    <message>
        <source>after the end of this event.</source>
        <translation>po začátku této události.</translation>
    </message>
    <message>
        <source>First cart has a</source>
        <translation>První vozík má</translation>
    </message>
    <message>
        <source>Imported carts have a</source>
        <translation type="unfinished">Zavedené vozíky mají</translation>
    </message>
    <message>
        <source>transition.</source>
        <translation type="unfinished">přechod.</translation>
    </message>
    <message>
        <source>Import inline traffic with the</source>
        <translation type="obsolete">Zavést vložený přenos s</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[žádný]</translation>
    </message>
    <message>
        <source>event.</source>
        <translation type="obsolete">událost.</translation>
    </message>
    <message>
        <source>POST-IMPORT CARTS</source>
        <translation>VOZÍKY PO ZAVEDENÍ</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Uložit</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Uložit &amp;jako</translation>
    </message>
    <message>
        <source>&amp;Services
List</source>
        <translation>Seznam
&amp;služeb</translation>
    </message>
    <message>
        <source>C&amp;olor</source>
        <translation>&amp;Barva</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation>RDLogManager</translation>
    </message>
    <message>
        <source>Event already exists!
Do you want to overwrite it?</source>
        <translation>Událost již existuje!
Chcete ji přepsat?</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation>Upravit událost</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation>Makro</translation>
    </message>
    <message>
        <source>Cue</source>
        <translation type="obsolete">CUE</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="obsolete">PŘECHOD</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="obsolete">ZASTAVIT</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="obsolete">PŘEHRÁT</translation>
    </message>
    <message>
        <source>, Timed(Start)</source>
        <translation type="obsolete">, Pevný (Začátek)</translation>
    </message>
    <message>
        <source>, Timed(MakeNext)</source>
        <translation type="obsolete">, Načasovaný (Jako další)</translation>
    </message>
    <message>
        <source>Timed(Wait</source>
        <translation type="obsolete">Načasovaný (Čekat</translation>
    </message>
    <message>
        <source>, Post</source>
        <translation type="obsolete">, Po</translation>
    </message>
    <message>
        <source>, Fill</source>
        <translation type="obsolete">, Vyplnit</translation>
    </message>
    <message>
        <source>, Scale</source>
        <translation type="obsolete">, Změnit velikost</translation>
    </message>
    <message>
        <source>, Traffic</source>
        <translation type="obsolete">, Přenos</translation>
    </message>
    <message>
        <source>, Music</source>
        <translation type="obsolete">, Hudba</translation>
    </message>
    <message>
        <source>, Scheduler</source>
        <translation type="obsolete">, Rozvrhovač</translation>
    </message>
    <message>
        <source>, Inline Traffic</source>
        <translation type="obsolete">, Vložený přenos</translation>
    </message>
    <message>
        <source>REMARKS</source>
        <translation type="obsolete">POZNÁMKY</translation>
    </message>
    <message>
        <source>Len:</source>
        <translation>Délka:</translation>
    </message>
    <message>
        <source>PRE-IMPORT CARTS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IMPORT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>and code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished">Délka</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished">Začátek</translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished">Konec</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Count</source>
        <translation type="unfinished">Počet</translation>
    </message>
    <message>
        <source>Artist Separation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRANSITIONS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CART STACK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import inline traffic event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>USER NOTES</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEventLine</name>
    <message>
        <source>Edit Event Assignment</source>
        <translation>Upravit přiřazení události</translation>
    </message>
    <message>
        <source>Event:</source>
        <translation>Událost:</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Vybrat</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Počáteční čas:</translation>
    </message>
    <message>
        <source>End Time:</source>
        <translation>Koncový čas:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Invalid Event</source>
        <translation>Neplatná událost</translation>
    </message>
    <message>
        <source>The event end time cannot be earlier than the start time.</source>
        <translation>Koncový čas události nemůže ležet před počáteční časem.</translation>
    </message>
    <message>
        <source>No Such Event</source>
        <translation>Žádná taková událost</translation>
    </message>
    <message>
        <source>There is no such event.</source>
        <translation>Není žádná taková událost.</translation>
    </message>
    <message>
        <source>This event overlaps with an
already existing event.</source>
        <translation>Tato událost se překrývá s již
existující událostí.</translation>
    </message>
</context>
<context>
    <name>EditGrid</name>
    <message>
        <source>Edit Grid:</source>
        <translation type="obsolete">Upravit mřížku:</translation>
    </message>
    <message>
        <source>Edit Clock</source>
        <translation>Upravit hodiny</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>Clear Hour</source>
        <translation>Smazat hodiny</translation>
    </message>
    <message>
        <source>Change
&amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Clocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to update ALL clocks in the grid?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This operation cannot be undone!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Grid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditNote</name>
    <message>
        <source>Edit Log Note</source>
        <translation>Upravit poznámku k zápisu</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
</context>
<context>
    <name>EditPerms</name>
    <message>
        <source>Service Associations</source>
        <translation>Přiřazení služeb</translation>
    </message>
    <message>
        <source>Available Services</source>
        <translation>Dostupné služby</translation>
    </message>
    <message>
        <source>Enabled Services</source>
        <translation>Povolené služby</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
</context>
<context>
    <name>EditSchedCodeRules</name>
    <message>
        <source>Edit Rules for Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">Z&amp;rušit</translation>
    </message>
    <message>
        <source>Code:</source>
        <translation type="unfinished">Kód:</translation>
    </message>
    <message>
        <source>Max. in a row:</source>
        <translation type="unfinished">Nejvíce za sebou:</translation>
    </message>
    <message>
        <source>Min. wait:</source>
        <translation type="unfinished">Nejmenší doba čekání:</translation>
    </message>
    <message>
        <source>Do not schedule after:</source>
        <translation type="unfinished">Nezařazovat po:</translation>
    </message>
    <message>
        <source>Or after:</source>
        <translation type="unfinished">nebo po:</translation>
    </message>
</context>
<context>
    <name>EditSchedRules</name>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Upravit</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Zavést</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>CODE</source>
        <translation>KÓD</translation>
    </message>
    <message>
        <source>MAX. IN A ROW</source>
        <translation>NEJVÍCE ZA SEBOU</translation>
    </message>
    <message>
        <source>MIN. WAIT</source>
        <translation>NEJMENŠÍ DOBA ČEKÁNÍ</translation>
    </message>
    <message>
        <source>DO NOT SCHEDULE AFTER</source>
        <translation>NEHRÁT PO</translation>
    </message>
    <message>
        <source>OR AFTER</source>
        <translation>NEBO PO</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>POPIS</translation>
    </message>
    <message>
        <source>Scheduler Codes:</source>
        <translation>Kódy rozvrhovače:</translation>
    </message>
    <message>
        <source>Rules Modified</source>
        <translation>Pravidla změněna</translation>
    </message>
    <message>
        <source>The rules have been modified.
Do you want to save?</source>
        <translation>Pravidla byla změněna.
Chcete je uložit?</translation>
    </message>
    <message>
        <source>Scheduler Rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist Separation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Rules from Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Žádný</translation>
    </message>
    <message>
        <source>(This setting is deprecated and has been moved to events)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditTrack</name>
    <message>
        <source>Edit Voice Track Marker</source>
        <translation>Upravit značku zápisu stopy hlasu</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
</context>
<context>
    <name>GenerateLog</name>
    <message>
        <source>Generating Log...</source>
        <translation>Vytváří se zápis...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Služba:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Datum:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vybrat</translation>
    </message>
    <message>
        <source>&amp;Create New Log</source>
        <translation>&amp;Vytvořit nový zápis</translation>
    </message>
    <message>
        <source>Merge &amp;Music</source>
        <translation>Sloučit &amp;hudbu</translation>
    </message>
    <message>
        <source>Merge &amp;Traffic</source>
        <translation>Sloučit &amp;přenos</translation>
    </message>
    <message>
        <source>Import Data</source>
        <translation>Zavést data</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Dostupné</translation>
    </message>
    <message>
        <source>Merged</source>
        <translation>Sloučeno</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>The log for</source>
        <translation>Zápis pro</translation>
    </message>
    <message>
        <source>already exists.  Recreating it
will remove any merged Music or Traffic events.

Recreate?</source>
        <translation type="obsolete">již existuje. Jeho znovuvytvoření odstraní
jakékoli události sloučené hudby nebo přenosu.

Vytvořit znovu?</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation>Zápis existuje</translation>
    </message>
    <message>
        <source>This will also delete the</source>
        <translation>Toto smaže i</translation>
    </message>
    <message>
        <source>voice tracks associated with this log.
Continue?</source>
        <translation type="obsolete">stopy hlasů spojených s tímto zápisem.
Pokračovat?</translation>
    </message>
    <message>
        <source>Tracks Exist</source>
        <translation>Stopa existuje</translation>
    </message>
    <message>
        <source>No Errors</source>
        <translation type="unfinished">Žádné chyby</translation>
    </message>
    <message>
        <source>No exceptions found.</source>
        <translation type="obsolete">Nenalezena žádná chyba.</translation>
    </message>
    <message>
        <source>already contains merged music and/or traffic data.
Remerging it will remove this data.  Remerge?</source>
        <translation type="obsolete">již obsahuje sloučená data hudby a/nebo přenosu.
Opětovné sloučení tato data smaže. Sloučit znovu?</translation>
    </message>
    <message>
        <source>Music Exists</source>
        <translation>Hudba existuje</translation>
    </message>
    <message>
        <source>already contains merged traffic data.  Remerging it
will remove this data.  Remerge?</source>
        <translation type="obsolete">již obsahuje sloučená data přenosu.
Opětovné sloučení tato data smaže. Sloučit znovu?</translation>
    </message>
    <message>
        <source>Traffic Exists</source>
        <translation>Přenos existuje</translation>
    </message>
    <message>
        <source>Generate Log - User: </source>
        <translation type="obsolete">Vytvořit zápis - Uživatel: </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to generate log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to clear traffic links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to clear music links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generate Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>already exists.  Recreating it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>will remove any merged Music or Traffic events.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recreate?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>voice tracks associated with this log.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>already contains merged music and/or traffic data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remerging it will remove this data.  Remerge?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>already contains merged traffic data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cannot be relinked.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No broken rules or validation exceptions found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogManager Error Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music schedule import failed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Traffic schedule import failed!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportListView</name>
    <message>
        <source>Insert Log Note</source>
        <translation>Vložit poznámku k zápisu</translation>
    </message>
    <message>
        <source>Edit Log Note</source>
        <translation>Upravit poznámku k zápisu</translation>
    </message>
    <message>
        <source>Insert Voice Track</source>
        <translation>Vložit stopu hlasu</translation>
    </message>
    <message>
        <source>Edit Voice Track</source>
        <translation>Upravit stopu hlasu</translation>
    </message>
    <message>
        <source>Set PLAY Transition</source>
        <translation type="obsolete">Nastavit přechod PŘEHRÁT</translation>
    </message>
    <message>
        <source>Set SEGUE Transition</source>
        <translation type="obsolete">Nastavit přechod PŘECHOD</translation>
    </message>
    <message>
        <source>Set STOP Transition</source>
        <translation type="obsolete">Nastavit přechod ZASTAVIT</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Značka</translation>
    </message>
    <message>
        <source>[Log Note]</source>
        <translation>[Poznámka k zápisu]</translation>
    </message>
    <message>
        <source>Track</source>
        <translation>Stopa</translation>
    </message>
    <message>
        <source>[Voice Track]</source>
        <translation>[Stopa hlasu]</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>PŘEHRÁT</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>PŘECHOD</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>ZASTAVIT</translation>
    </message>
    <message>
        <source>PLAY Transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SEGUE Transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[auto]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListClocks</name>
    <message>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Code</source>
        <translation>Kód</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Přidat</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Upravit</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>S&amp;mazat</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Přejmenovat</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation>&amp;Vyprázdnit</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>VŠE</translation>
    </message>
    <message>
        <source>NONE</source>
        <translation>ŽÁDNÝ</translation>
    </message>
    <message>
        <source>Clock Exists</source>
        <translation>Hodiny existují</translation>
    </message>
    <message>
        <source>An clock with that name already exists!</source>
        <translation>Hodiny s tímto názvem již existují!</translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation type="obsolete">Jste si jistý, že chcete smazat</translation>
    </message>
    <message>
        <source>Delete Clock</source>
        <translation>Smazat hodiny</translation>
    </message>
    <message>
        <source>is in use in the following grid(s):</source>
        <translation type="obsolete">se používá následující mřížkou(ami):</translation>
    </message>
    <message>
        <source>Do you still want to delete it?</source>
        <translation>Stále ještě chcete smazat?</translation>
    </message>
    <message>
        <source>Clock In Use</source>
        <translation>Používané hodiny</translation>
    </message>
    <message>
        <source>Log Clocks - User: </source>
        <translation type="obsolete">Zápis - Uživatel hodin:</translation>
    </message>
    <message>
        <source>Log Clocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is in use in the following grid(s)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListEvents</name>
    <message>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Vlastnosti</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="obsolete">Barva</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Přidat</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Upravit</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>S&amp;mazat</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Přejmenovat</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>VŠE</translation>
    </message>
    <message>
        <source>NONE</source>
        <translation>ŽÁDNÝ</translation>
    </message>
    <message>
        <source>Event Exists</source>
        <translation>Událost existuje</translation>
    </message>
    <message>
        <source>An event with that name already exists!</source>
        <translation>Událost s tímto názvem již existuje!</translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation type="obsolete">Jste si jistý, že chcete smazat</translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation>Smazat událost</translation>
    </message>
    <message>
        <source>is in use in the following clocks:</source>
        <translation type="obsolete">se používá následujícími hodinami:</translation>
    </message>
    <message>
        <source>Do you still want to delete it?</source>
        <translation>Stále ještě chcete smazat?</translation>
    </message>
    <message>
        <source>Event In Use</source>
        <translation>Používaná událost</translation>
    </message>
    <message>
        <source>Log Events - User: </source>
        <translation type="obsolete">Zápis - Události - Uživatel:</translation>
    </message>
    <message>
        <source>Log Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is in use in the following clocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trans</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListGrids</name>
    <message>
        <source>Log Grids</source>
        <translation>Mřížky zápisu</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Upravit</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Zavřít</translation>
    </message>
</context>
<context>
    <name>ListSvcs</name>
    <message>
        <source>Rivendell Services</source>
        <translation>Služby Rivendell</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="obsolete">SLUŽBA</translation>
    </message>
    <message>
        <source>OLDEST REPORT</source>
        <translation type="obsolete">NEJSTARŠÍ ZPRÁVA</translation>
    </message>
    <message>
        <source>&amp;Generate
Reports</source>
        <translation>&amp;Vytvořit
zprávy</translation>
    </message>
    <message>
        <source>&amp;Purge
Data</source>
        <translation>&amp;Smazat
data</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[žádný]</translation>
    </message>
    <message>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Oldest Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">Nelze spojit</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation>RDLogManager</translation>
    </message>
    <message>
        <source>Select an operation:</source>
        <translation>Vyberte operaci:</translation>
    </message>
    <message>
        <source>Edit &amp;Events</source>
        <translation>Upravit &amp;události</translation>
    </message>
    <message>
        <source>Edit C&amp;locks</source>
        <translation>Upravit &amp;hodiny</translation>
    </message>
    <message>
        <source>Edit G&amp;rids</source>
        <translation>Upravit &amp;mřížky</translation>
    </message>
    <message>
        <source>&amp;Generate Logs</source>
        <translation>&amp;Vytvořit zápisy</translation>
    </message>
    <message>
        <source>Manage &amp;Reports</source>
        <translation>Spravovat zpráv&amp;y</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>RDLogManager - User: </source>
        <translation type="obsolete">RDLogManager - Uživatel: </translation>
    </message>
    <message>
        <source>RDLogEdit -- Database Skew</source>
        <translation type="obsolete">RDLogEdit - Nesouměrnost v databázi</translation>
    </message>
    <message>
        <source>This version of RDLogManager is incompatible with the version installed on the server.
See your system administrator for an update!</source>
        <translation type="obsolete">Tato verze RDLogManager je neslučitelná s verzí nainstalovanou na serveru.
Vyhledejte svého správce systému kvůli aktualizaci!</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PickReportDates</name>
    <message>
        <source>Select Report Dates</source>
        <translation>Vybrat data zprávy</translation>
    </message>
    <message>
        <source>&amp;Report:</source>
        <translation>&amp;Zpráva:</translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation>&amp;Počáteční datum:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vybrat</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation>&amp;Koncové datum:</translation>
    </message>
    <message>
        <source>&amp;Generate
Report</source>
        <translation>&amp;Vytvořit
zprávu</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>Invalid Date Range</source>
        <translation>Neplatný rozsah data</translation>
    </message>
    <message>
        <source>The end date cannot be earlier than the start date!</source>
        <translation>Koncové datum se nemůže nacházet před počáteční datem!</translation>
    </message>
    <message>
        <source>This report type cannot span multiple dates!</source>
        <translation>Tato zpráva nemůže zahrnout více dní!</translation>
    </message>
    <message>
        <source>This report type cannot span multiple months!</source>
        <translation>Tato zpráva nemůže zahrnout více měsíců!</translation>
    </message>
    <message>
        <source>Report Complete</source>
        <translation type="obsolete">Zpráva úplná</translation>
    </message>
    <message>
        <source>Report complete!</source>
        <translation type="obsolete">Zpráva úplná!</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open report file at</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The report file already exists.  Overwrite?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameItem</name>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Name Conflict</source>
        <translation>Střet názvů</translation>
    </message>
    <message>
        <source>That name already exists!</source>
        <translation>Název již existuje!</translation>
    </message>
</context>
<context>
    <name>SvcRec</name>
    <message>
        <source>Mo</source>
        <translation>Po</translation>
    </message>
    <message>
        <source>Tu</source>
        <translation>Út</translation>
    </message>
    <message>
        <source>We</source>
        <translation>St</translation>
    </message>
    <message>
        <source>Th</source>
        <translation>Čt</translation>
    </message>
    <message>
        <source>Fr</source>
        <translation>Pá</translation>
    </message>
    <message>
        <source>Sa</source>
        <translation>So</translation>
    </message>
    <message>
        <source>Su</source>
        <translation>Ne</translation>
    </message>
</context>
<context>
    <name>SvcRecDialog</name>
    <message>
        <source>Report Data</source>
        <translation>Data zprávy</translation>
    </message>
    <message>
        <source>&amp;Purge
Data</source>
        <translation>&amp;Smazat
data</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>Delete Report Data</source>
        <translation>Smazat data zprávy</translation>
    </message>
    <message>
        <source>Are you sure you want to delete report data for</source>
        <translation>Jste si jistý, že chcete smazat data zprávy pro</translation>
    </message>
</context>
<context>
    <name>editSchedCodeRules</name>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">Z&amp;rušit</translation>
    </message>
    <message>
        <source>Code:</source>
        <translation type="obsolete">Kód:</translation>
    </message>
    <message>
        <source>Max. in a row:</source>
        <translation type="obsolete">Nejvíce za sebou:</translation>
    </message>
    <message>
        <source>Min. wait:</source>
        <translation type="obsolete">Nejmenší doba čekání:</translation>
    </message>
    <message>
        <source>Do not schedule after:</source>
        <translation type="obsolete">Nezařazovat po:</translation>
    </message>
    <message>
        <source>Or after:</source>
        <translation type="obsolete">nebo po:</translation>
    </message>
</context>
</TS>
